extensions [ time ]
globals [
  week                           ;week number (1 to 14)
  dt                             ;date
  judt                           ;Julian date
  hy-bl                          ;hatch year robin
  ahy-bl                         ;adult robin
  count-inf-culex                ;number of infected mosquitoes
  prop-inf-culex                 ;proportion of infected mosquitoes
  count-stressed-robins          ;number of stressed robins
  prop-stressed-robins           ;proportion of stressed robins
  cum-winc-culex                 ;cumulative weekly incidence Culex
  ]
breed [ robins robin ]
breed [ culex a-culex ]
robins-own [
  age-class                      ;hy (hatch-year) and ahy (adult)
  status                         ;ns not stressed s stressed
  viremia                        ;0 uninfected, below 4 noninfectious, above 4 infectious
  dpi                            ;days post infection; 0 for uninfected birds
  imm                            ;0 not immune, 1 immune
  ]
culex-own [
  inf-status                     ;sus 0/inf 1
  ip                             ;incubation period of WNV inside a mosquito
  eip                            ;Extrinsic incubation period at 23 °C (days)	9 (7–11)- set for each mosquito
]
patches-own [ ]

to setup
  clear-all
  set dt time:create "07-31"
  set judt 212
  ask patches [
    set pcolor green + 1
    ]
  create-robins pop-size                       ;The model is populated with robins as per the use-specified parameter 'pop-size'
  [ robin-attributes                           ;set individual attributes of the bird like color,size, location in the model landscape
    ifelse random 100 <= 80                    ;80% of the robins are setup as hatch-year and 20% as adults
    [ set age-class "hy"
      let prop-imm-hy 7 + random 4             ;7-10% of the hatch-years have immunity
      ifelse random 100 <= prop-imm-hy
      [ set imm 1 ]
      [ set imm 0 ]
      ]
    [ set age-class "ahy"
      let prop-imm-hy 17 + random 17            ;17-33% of the adults have immunity
      ifelse random 100 <= prop-imm-hy
      [ set imm 1 ]
      [ set imm 0 ]
      ]
    set status "ns"                             ;All robins are setup as not stressed
  ]

  set hy-bl count robins with [ age-class = "hy" ]
  set ahy-bl count robins with [ age-class = "ahy" ]
  if ini-inf-rate > 0 [                                            ;Procedure to setup initial WNV prevalence in the robin population
    ask n-of round (count robins * ini-inf-rate) robins [
      set dpi 1
      set color red
      set viremia random 5
    ]
  ]
  let num-culex (count robins * culex-to-host-ratio)               ;Procedure to setup the mosquito population
  create-culex num-culex
  [ set size 0.25
    set shape "bug"
    set color black
    setxy random-pxcor random-pycor                                ;mosquitoes are randomly located in the model landscape
    rt random 360
    fd random 2
    set inf-status 0
    set ip 0
    set eip random-normal 9 0.5                                     ;Extrinsic incubation period at 23 °C (days)	9 (7–11)
  ]
  if not file-exists? (word "../results/viremiadynamics.csv") [                  ;Create a file to document model data
    file-open (word "../results/viremiadynamics.csv")
    file-print "day,ddt,count-stressed-robins,prop-stressed-robins,count-inf-culex,prop-inf-culex,cum-wk-inc"
    file-close
    ]
  reset-ticks
end
to-report d
  report remainder ticks 7 + 1              ;day of the week
end
to-report ddt
  report time:show dt "MMMM d"
end

to go
  if ticks = 92 [ stop ]                    ;stop condition
  set dt time:plus dt 1 "day"
  set judt judt + 1
  set week (floor (ticks / 7) + 1)
  if d = 1                                  ;1st day of a week
  [
    let n-hy-robins count robins with [ age-class = "hy" ]
    let n-ahy-robins count robins with [ age-class = "ahy" ]
    let n-hy-robins-depart round (0.95 * n-hy-robins)                                  ;hatch-year robins departing this week (95% turnover)
    let hy-nonviremic count robins with [ age-class = "hy" and (dpi < 1 or dpi > 6) ]  ;hatch-year non-viremic robins that can actually depart
    if n-hy-robins-depart > hy-nonviremic [
      set n-hy-robins-depart hy-nonviremic
      ]
    let n-ahy-robins-depart round (0.95 * n-ahy-robins)                                 ;calculate the number of adult robins departing this week (95% turnover)
    let ahy-nonviremic count robins with [ age-class = "ahy" and (dpi < 1 or dpi > 6) ] ;non-viremic adult robins that can actually depart
    if n-ahy-robins-depart > ahy-nonviremic [
      set n-ahy-robins-depart ahy-nonviremic
      ]
    let n-hy-robins-staying (n-hy-robins - n-hy-robins-depart)
    let n-ahy-robins-staying (n-ahy-robins - n-ahy-robins-depart)
    let n-hy-robins-arrive n-hy-robins-depart                                           ;number of hatch-year robins arriving this week
    let n-ahy-robins-arrive n-ahy-robins-depart                                         ;number of adult robins arriving this week

    ask n-of n-hy-robins-depart robins with [ age-class = "hy" and (dpi < 1 or dpi > 6) ] [ die ]         ;departure of hatch year robins is simulated
    ask n-of n-ahy-robins-depart robins with [ age-class = "ahy" and (dpi < 1 or dpi > 6) ] [ die ]       ;departure of adult robins is simulated

    if (ddt != "September 19" or ddt != "October 10")                                  ;Process to simulate greater influx during the two weeks
    [ create-robins n-hy-robins-arrive
      [ robin-attributes
        set age-class "hy"
        let prop-imm-hy 7 + random 4                  ;7-10% of the hatch-years have immunity
        ifelse random 100 <= prop-imm-hy
        [ set imm 1 ]
        [ set imm 0 ]
      ]
      create-robins n-ahy-robins-arrive
      [ robin-attributes
        set age-class "ahy"
        let prop-imm-hy 17 + random 17                 ;17-33% of adults have immunity
        ifelse random 100 <= prop-imm-hy
        [ set imm 1 ]
        [ set imm 0 ]
      ]
    ]
    if ddt = "September 19"
    [ let n-robins-arriving-this-week (2 * (hy-bl + ahy-bl))
      let n-ahy-arriving-this-week round (0.4 * n-robins-arriving-this-week)
      let n-hy-arriving-this-week round (0.6 * n-robins-arriving-this-week)
      set n-ahy-robins-arrive (n-ahy-arriving-this-week - n-ahy-robins-staying)
      set n-hy-robins-arrive (n-hy-arriving-this-week - n-hy-robins-staying)
      create-robins n-hy-robins-arrive
      [ robin-attributes
        set age-class "hy"
        let prop-imm-hy 7 + random 4                   ;7-10% of the hatch-years have immunity
        ifelse random 100 <= prop-imm-hy
        [ set imm 1 ]
        [ set imm 0 ]
      ]
      create-robins n-ahy-robins-arrive
      [ robin-attributes
        set age-class "ahy"
        let prop-imm-hy 17 + random 17                 ;17-33% of adults have immunity
        ifelse random 100 <= prop-imm-hy
        [ set imm 1 ]
        [ set imm 0 ]
      ]
      ]
    if ddt = "October 10"
    [ let n-robins-arriving-this-week (5 * (hy-bl + ahy-bl))
      let n-ahy-arriving-this-week round (0.3 * n-robins-arriving-this-week)
      let n-hy-arriving-this-week round (0.7 * n-robins-arriving-this-week)
      set n-ahy-robins-arrive (n-ahy-arriving-this-week - n-ahy-robins-staying)
      set n-hy-robins-arrive (n-hy-arriving-this-week - n-hy-robins-staying)
      create-robins n-hy-robins-arrive
      [ robin-attributes
        set age-class "hy"
        let prop-imm-hy 7 + random 4               ;7-10% of the hatch-years have immunity
        ifelse random 100 <= prop-imm-hy
        [ set imm 1 ]
        [ set imm 0 ]
      ]
      create-robins n-ahy-robins-arrive
      [ robin-attributes
        set age-class "ahy"
        let prop-imm-hy 17 + random 17             ;17-33% of adults have immunity
        ifelse random 100 <= prop-imm-hy
        [ set imm 1 ]
        [ set imm 0 ]
      ]
    ]
    stress-status-update                           ;Process to update stress status of robins
    ]
  ask patches [ set pcolor green + 1 ]             ;Process to highlight patches with infected mosquitoes
  ask culex with [ inf-status = 1 ] [
    ask patches in-radius 1.5 [
      set pcolor [ color ] of myself
      ]
    ]
  ask robins [
    disease-progression                            ;turtle procedure - disease progression in robins
    ]
  ask culex [
    if ip > 0 [ set ip ip + 1 ]                    ;turtle procedure - days since exposure counter updated in infected Culex
    c-mortality                                    ;turtle procedure - Culex mortality
    if random-float 1 < 0.16 [
      bite
      ]
    ]
  set-current-plot "Viremic robins"                ;Plot and document data in a .csv output file
  set-current-plot-pen "stressed"
  plotxy judt count robins with [ status = "s" and viremia > 4 ]
  set-current-plot-pen "not stressed"
  plotxy judt count robins with [ status = "ns" and viremia > 4 ]
  set count-inf-culex count culex with [ inf-status = 1 ]
  set prop-inf-culex count-inf-culex / count culex
  set count-stressed-robins count robins with [ status = "s" ]
  set prop-stressed-robins count-stressed-robins / count robins
  file-open (word "../results/viremiadynamics.csv")
  file-type d file-type "," file-type ddt file-type "," file-type count-stressed-robins file-type "," file-type precision (prop-stressed-robins) 2 file-type "," file-type count-inf-culex file-type "," file-type precision (prop-inf-culex) 3 file-type "," file-type (cum-winc-culex)
  file-print ""
  file-close
  if d = 7 [ set cum-winc-culex 0 ]
  tick
end

to stress-status-update
  ask robins with [ dpi < 1 or dpi > 6 ] [           ;First, the stress status of all uninfected and recovered robins is set to unstressed
    set status "ns"
    ]
  ask n-of round (count robins * stressed-prop) robins with [ dpi < 1 or dpi > 6 ] [   ;Then the user-specified proportion of these birds are changed to 'stressed' status
    set status "s"
    set size 1.5
    ]
end

to robin-attributes
  set shape "bird side"
  set color yellow
  set size 1.5
  set dpi 0
  set viremia 0
  setxy random-pxcor random-pycor                       ;robins are randomly located in the model landscape
end

to disease-progression
  if dpi > 0
  [ set dpi dpi + 1
    ]
  if dpi = 2
  [ ifelse status = "s"
    [ ifelse random-float 1 <= 0.9
      [ set viremia 5 + random 4 ]                      ;90% of stressed infected birds have viremia between 5 and 8
      [ set viremia 1 + random 4 ]                      ;10% of stressed infected birds have viremia between 1 and 4
      ]
    [ ifelse random-float 1 <= 0.7
        [ set viremia 5 + random 4 ]                    ;70% of normal infected birds have viremia between 5 and 8
        [ set viremia 1 + random 4 ]                    ;30% of normal infected birds have viremia between 1 and 4
      ]
    ]
  if dpi = 3
  [ ifelse viremia >= 5
    [ ifelse status = "s"
      [ ifelse random-float 1 <= 0.63
        [ set viremia viremia + random 3 ]
        [ set viremia 1 + random 4 ]
        ]
      [ ifelse random-float 1 <= 0.21
        [ set viremia viremia + random 3 ]
        [ set viremia 1 + random 4 ]
        ]
      ]
    [ set viremia viremia - random 3
      if viremia < 0 [ set viremia 0 ]
      ]
    ]
  if dpi = 4
  [ ifelse viremia >= 5
    [ ifelse status = "s"
      [ ifelse random-float 1 <= 0.35
        [ set viremia viremia + random 3 ]
        [ set viremia 1 + random 4 ]
        ]
      [ ifelse random-float 1 <= 0.03
        [ set viremia viremia + random 3 ]
        [ set viremia 1 + random 4 ]
        ]
      ]
    [ set viremia viremia - random 3
      if viremia < 0 [ set viremia 0 ]
      ]
    ]
  if dpi = 5
  [ ifelse viremia >= 5
    [ ifelse status = "s"
      [ if random-float 1 <= 0.1 [ die ]                          ;10% of the stressed infectious birds die on dpi 5
        ifelse random-float 1 <= 0.15
        [ set viremia viremia + random 3 ]
        [ set viremia 1 + random 4 ]
        ]
      [ ;if random-float 1 <= 0.1 [ die ]                         ;10% of the stressed non-infectious birds die on dpi 5
        ifelse random-float 1 <= 0.01
        [ set viremia viremia + random 3 ]
        [ set viremia 1 + random 4 ]
        ]
      ]
    [ set viremia viremia - random 3
      if viremia < 0 [ set viremia 0 ]
      ]
    ]
  if dpi = 6
  [ set viremia 0
    set imm 1
    set color violet
    if status = "s" [
      if random-float 1 <= 0.11 [
        die
        ]
      ]
    ]
end
to c-mortality
  if random-float 1 < 0.05                                        ;Culex daily mortality probability
  [ hatch-culex 1                                                  ;each dying Culex is replaced by a new Culex mosquito
    [ set size 0.25
      set shape "bug"
      set color black
      setxy random-pxcor random-pycor
      rt random 360
      fd random 2
      set inf-status 0
      set ip 0
      set eip random-normal 9 0.5
      ]
    die
    ]
end
to bite
  if inf-status = 1  and ip >= eip                                   ;Extrinsic incubation period at 23 °C (days)	9 (7–11)
  [ let n-bites 1 + random 5                                          ;an infected mosquito can bite many susceptible or infected birds, here we assume at least 1 and a max of 5
    ask n-of n-bites robins [
    ;ask min-n-of n-bites robins [ distance myself ] [                ;host questing on its own patch or in a radius of upto 4 patches
     if imm = 0 [ ;viremia = 0 [
       if random-float 1 < 0.81 [                                     ;Transmission probability mosquito to bird	0.80
          set dpi 1
          set color red
          set viremia random 5
        ]
      ]
    ]
  ]
  if inf-status = 0
  [ let n-bites 1 + random 5                                           ;an infected mosquito can bite many susceptible or infected birds, here we assume at least 1 and a max of 5
    let b-m-trans 0
    ask n-of n-bites robins [
    ;ask min-n-of n-bites robins [ distance myself ] [                 ;host questing on its own patch or in a radius of upto 4 patches
      if viremia > 4 [
        ;derive from a distribution with a mean 0.09 and sd 0.08
        if random-float 1 < 0.05 + random-float 0.26 [                 ;Transmission probability bird to pipiens
          set b-m-trans b-m-trans + 1
        ]
      ]
    ]
    if b-m-trans > 0
    [ set inf-status 1
      set cum-winc-culex cum-winc-culex + 1
      set ip 1
      set size 0.5
      set color magenta
      ]
    ]
end
@#$#@#$#@
GRAPHICS-WINDOW
210
10
686
487
-1
-1
12.0
1
10
1
1
1
0
1
1
1
0
38
0
38
0
0
1
ticks
30.0

SLIDER
22
100
194
133
pop-size
pop-size
0
1000
500.0
100
1
NIL
HORIZONTAL

BUTTON
28
42
91
75
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
128
43
191
76
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
21
144
193
177
ini-inf-rate
ini-inf-rate
0
1
0.1
0.01
1
NIL
HORIZONTAL

SLIDER
21
189
193
222
stressed-prop
stressed-prop
0
1
0.3
0.01
1
NIL
HORIZONTAL

PLOT
720
327
1005
514
Viremic robins
days
number of viremic robins
210.0
300.0
0.0
5.0
true
true
"" ""
PENS
"stressed" 1.0 0 -2674135 true "" ""
"not stressed" 1.0 0 -13345367 true "" ""

SLIDER
21
241
193
274
culex-to-host-ratio
culex-to-host-ratio
0
250
20.0
10
1
NIL
HORIZONTAL

MONITOR
703
280
787
325
Infected robins
count robins with [ viremia > 0 ]
17
1
11

MONITOR
1032
277
1114
322
Infected culex
count culex with [ inf-status = 1 ]
17
1
11

PLOT
1050
324
1322
509
infected culex
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot count culex with [ inf-status = 1 ]"

MONITOR
1120
277
1243
322
WNV prevalence Culex
(count culex with [ inf-status = 1 ] / count culex)
17
1
11

MONITOR
792
280
917
325
WNV prevalence Robins
precision (count robins with [ viremia > 0 ] / count robins) 2
17
1
11

MONITOR
864
14
921
59
Week
week
17
1
11

MONITOR
704
14
779
59
Date
ddt
17
1
11

MONITOR
927
15
984
60
Day
d
17
1
11

MONITOR
788
14
857
59
Julian date
judt
0
1
11

MONITOR
921
279
1015
324
Robin abundance
count robins
17
1
11

MONITOR
998
90
1121
135
Hatch-year abundance
count robins with [ age-class = \"hy\"]
17
1
11

MONITOR
999
163
1122
208
Adult abundance
count robins with [ age-class = \"ahy\"]
17
1
11

PLOT
705
78
995
257
Robin abundance
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"hy" 1.0 0 -955883 true "" "plot count robins with [ age-class = \"hy\" ]"
"ahy" 1.0 0 -5825686 true "" "plot count robins with [ age-class = \"ahy\" ]"

MONITOR
1246
276
1340
321
Culex abundance
count culex
17
1
11

@#$#@#$#@
## WHAT IS IT?

AMRO_CULEX_WNV simulates transmission dynamics of West Nile virus between an avian reservoir host (American robin, *Turdus migratorius*) and its primary mosquito vector (Culex spp.). The main objective is to quantify how acute food stress experienced by robins influences the prevalence of infected Culex mosquitoes during peak fall migration when there are large influxes and turnover of robins, particularly susceptible, hatch-year birds. 

## HOW IT WORKS

AMRO_CULEX_WNV has a daily time step and the model is simulated for 92 days (from 1st August to 31st October). Robin population dynamics in the model is driven by migratory events, we do not simulate births or natural mortality. The changes in robin population size, age ratio, and herd immunity are derived from a long-term banding data set (Owen unpublished data) and from WNV serosurveillance in robins in MI and NY (Dupuis and Owen unpublished data). On the first day of each week, uninfected individuals and those with virus titers below 4 logs are selected randomly to ‘depart’ from the model landscape so as to have a 95% population turnover. An equal number of robins ‘arrive’ in the model landscape simultaneously. The initial age ratio (0.20AHY: 0.80HY) changes twice during the model run. On 19 September (50th day of the model run), the robin population doubles with a large influx of birds with the age ratio of 0.40AHY / 0.60HY. On 10 October (71st day of the model run), another large influx of robins increases the population five times the initial population size with an age ratio of 0.30AHY / 0.70HY.

Also on the first day of every week, randomly selected robins are assigned ‘stressed’ status.

Infected birds in the model recover at a constant rate of 0.17 as the average duration of infection (viremia) in robins is 6 days. Mosquitoes do not recover from infection in the model as they have a short lifespan. The daily natural mortality probability for Culex mosquito at 23° Celsius is 0.04 derived from (Vogels et al. 2017).

We use the temperature-dependent biting rate (the number of bites per day, or the reciprocal of the number of days between blood meals) of 0.17 (at 23°C) (Wonham et al. 2004, Vogels et al. 2017) to model the number of Culex mosquitoes seeking a blood meal during each time step. The transmission probability of WNV transmission from a robin with viremia above 4 to a susceptible mosquito is set at 0.15 (with range of 0.05 – 0.30 (Turell et al. 2001, Turell et al. 2005, Kilpatrick et al. 2010). The probability of WNV transmission from an infected Culex mosquito to a susceptible robin is set at 0.8 (Kushmaro et al. 2015, Vogels et al. 2017).
 

## HOW TO USE IT

Host and vector populations in the model are initialized with four user-specified parameters (set using the sliders provided on the interface): initial robin population size, WNV prevalence in robins, proportion of stressed robins and mosquito: host ratio. The initial age ratio for the robin population is set at 0.20 AHY to 0.80 HY.

The monitors and plots on the interface document the number of infected mosquitoes and the number of infected and the number of viremic robins (stressed and not stressed) in the model. 

## THINGS TO NOTICE

Notice how food stress (proportion of stressed robins in the population) affects the prevalence of infected birds and the prevalence of viremic birds.

## THINGS TO TRY

Also try changing the other sliders (pop-size, ini-inf-rate, culex-to-host-ratio) to assess the effect of robin population size, initial prevalence in robins, and mosquito population size on WNV risk (infection rate in mosquiotes and number of viremic birds in the model). 

## EXTENDING THE MODEL

The model could be extended beyond the migration season to simulate year round WNV dynamics.

## NETLOGO FEATURES

We have used the time extension to simulate discrete migration related influx in the model population.

## RELATED MODELS


## CREDITS AND REFERENCES

Kushmaro, A., Friedlander, T. A., & Levins, R. (2015). Temperature Effects on the Basic Reproductive Number (R0) Of West Nile Virus, Based On Ecological Parameters: Endemic Vs. New Emergence Regions. Journal of Tropical Diseases. doi:10.4172/2329-891x.1000s1-001

Vogels, C. B. F., Hartemink, N., & Koenraadt, C. J. M. (2017). Modelling West Nile virus transmission risk in Europe: Effect of temperature and mosquito biotypes on the basic reproduction number. Scientific Reports. doi:10.1038/s41598-017-05185-4
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

bird side
false
0
Polygon -7500403 true true 0 120 45 90 75 90 105 120 150 120 240 135 285 120 285 135 300 150 240 150 195 165 255 195 210 195 150 210 90 195 60 180 45 135
Circle -16777216 true false 38 98 14

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.1.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name=".1stress100iterations" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <enumeratedValueSet variable="pop-size">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stressed-prop">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="culex-to-host-ratio">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ini-inf-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name=".2stress100iterations" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <enumeratedValueSet variable="pop-size">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stressed-prop">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="culex-to-host-ratio">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ini-inf-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name=".3stress100iterations" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <enumeratedValueSet variable="pop-size">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stressed-prop">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="culex-to-host-ratio">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ini-inf-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name=".4stress100iterations" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <enumeratedValueSet variable="pop-size">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stressed-prop">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="culex-to-host-ratio">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ini-inf-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name=".5stress100iterations" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <enumeratedValueSet variable="pop-size">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stressed-prop">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="culex-to-host-ratio">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ini-inf-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="nostress100iterations" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <enumeratedValueSet variable="pop-size">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stressed-prop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="culex-to-host-ratio">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ini-inf-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="new0s" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <enumeratedValueSet variable="pop-size">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stressed-prop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="culex-to-host-ratio">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ini-inf-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="new25s" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <enumeratedValueSet variable="pop-size">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stressed-prop">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="culex-to-host-ratio">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ini-inf-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="new50s" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <enumeratedValueSet variable="pop-size">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stressed-prop">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="culex-to-host-ratio">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ini-inf-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="new10s" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <enumeratedValueSet variable="pop-size">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stressed-prop">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="culex-to-host-ratio">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ini-inf-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="new10s" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <enumeratedValueSet variable="pop-size">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stressed-prop">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="culex-to-host-ratio">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ini-inf-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="new10s_10ch" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <enumeratedValueSet variable="pop-size">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stressed-prop">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="culex-to-host-ratio">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ini-inf-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="new10_100ch" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <enumeratedValueSet variable="pop-size">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stressed-prop">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="culex-to-host-ratio">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ini-inf-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="10s_100ch" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <enumeratedValueSet variable="pop-size">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stressed-prop">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="culex-to-host-ratio">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ini-inf-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="10100ch" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <enumeratedValueSet variable="pop-size">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stressed-prop">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="culex-to-host-ratio">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ini-inf-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="0s_100ch" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <enumeratedValueSet variable="pop-size">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stressed-prop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="culex-to-host-ratio">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ini-inf-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="10s20ch" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <enumeratedValueSet variable="pop-size">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stressed-prop">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="culex-to-host-ratio">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ini-inf-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="10stress20ch" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <enumeratedValueSet variable="pop-size">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stressed-prop">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="culex-to-host-ratio">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ini-inf-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ch20_s0" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <enumeratedValueSet variable="pop-size">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stressed-prop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="culex-to-host-ratio">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ini-inf-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ch20s10" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <enumeratedValueSet variable="pop-size">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stressed-prop">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="culex-to-host-ratio">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ini-inf-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ch20s25" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <enumeratedValueSet variable="pop-size">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stressed-prop">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="culex-to-host-ratio">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ini-inf-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ch20s50" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <enumeratedValueSet variable="pop-size">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stressed-prop">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="culex-to-host-ratio">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ini-inf-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
